<?php
/**
 * Theme functions and definitions
 *
 * @package yuma_store
 */  

if ( ! function_exists( 'yuma_store_enqueue_styles' ) ) :
	/**
	 * Load assets.
	 *
	 * @since 1.0.0
	 */
	function yuma_store_enqueue_styles() {
		wp_enqueue_style( 'yuma-parent-style', get_template_directory_uri() . '/style.css' );
		wp_enqueue_style( 'yuma-store-style', get_stylesheet_directory_uri() . '/style.css', array('yuma-parent-style') );
	}
endif;
add_action( 'wp_enqueue_scripts', 'yuma_store_enqueue_styles' );

if ( ! function_exists( 'yuma_store_theme_defaults' ) ) :
    /**
     * Customize theme defaults.
     *
     * @since 1.0.0
     *
     * @param array $defaults Theme defaults.
     * @param array Custom theme defaults.
     */
    function yuma_store_theme_defaults( $defaults ) {
        // theme color
        $defaults['theme_color'] = 'custom';
        $defaults['color_primary'] = '#000000';
        $defaults['color_secondary'] = '#999999';

        // typography
        $defaults['body_font_family'] = json_encode(array('font' => 'Oxygen') );
        $defaults['heading_font_family'] = json_encode(array('font' => 'Lato') );
        $defaults['section_title_font_family'] = json_encode(array('font' => 'Lato') );
        $defaults['home_title_font_family'] = json_encode(array('font' => 'Lato') );
        $defaults['page_title_font_family'] = json_encode(array('font' => 'Lato') );
        $defaults['entry_title_font_family'] = json_encode(array('font' => 'Lato') );
        $defaults['entry_meta_font_family'] = json_encode(array('font' => 'Oxygen') );

        // topbar section
        $defaults['topbar_border_height'] = 1;
        $defaults['enable_topbar_woocart_item'] = true;
        $defaults['topbar_address'] = esc_html__( 'Brooklyn, New York', 'yuma-store' );

        // // header section
        $defaults['header_height'] = 110;
        $defaults['header_right_element'] = 'social_menu,search';
        $defaults['header_border_height'] = 1;
        
        // // latest blog
        $defaults['enable_blog_before_element'] = false;
        $defaults['blog_column_type'] = 'column-2';
        $defaults['latest_blog_sidebar'] = true;
        $defaults['filter_blog_posts'] = 'none';
        
        // single post
        $defaults['single_header_image_layout'] = 'banner-featured-image';
        $defaults['enable_single_title_banner'] = true;
        $defaults['show_single_breadcrumb'] = true;
        $defaults['single_title_alignment'] = 'center-align';
        
        // page
        $defaults['page_header_image_layout'] = 'banner-featured-image';
        $defaults['enable_page_title_banner'] = true;
        $defaults['show_page_breadcrumb'] = true;
        $defaults['page_title_alignment'] = 'center-align';
        $defaults['show_static_page_title'] = false;
        $defaults['show_static_page_image'] = false;
        
        // archive
        $defaults['enable_blog_title_banner'] = true;
        $defaults['show_breadcrumb'] = true;
        $defaults['blog_title_alignment'] = 'center-align';

        return $defaults;
    }
endif;
add_filter( 'yuma_default_theme_options', 'yuma_store_theme_defaults', 99 );

if ( ! function_exists( 'yuma_store_set_theme_mods' ) ) :
    /**
     * Set theme mod.
     */
    function yuma_store_set_theme_mods() {
        $theme_mod = get_theme_mod( 'yuma_theme_options' );
        if ( isset( $theme_mod ) && $theme_mod ) {
            return;
        }

        $yuma_theme_options = array( 
            // topbar section
            'topbar_left_element' => 'address,phone',
            'topbar_right_element' => 'cart',
            'topbar_bg_color' => '#ffffff',
            'topbar_elements_color' => '#0a0e14',
            'topbar_dropdown_icon_color' => '#0a0e14',
            'topbar_border_color' => 'rgba(0,0,0,0.1)',
            
            // header section
            'header_center_element' => 'primary_menu',

            // single post
            'single_header_image_overlay_color' => 'rgba(0,0,0,0.3)',

            // page
            'page_header_image_overlay_color' => 'rgba(0,0,0,0.3)',

            // footer widget area
            'footer_bg_color' => '#000000',
            'footer_widget_bg_color' => '#000000',
            
            // footer btt
            'btt_bg_color' => 'rgba(0,0,0,0)',
            'btt_bg_hover_color' => 'rgba(0,0,0,0)',
            'btt_elements_color' => '#555555',
            'btt_elements_hover_color' => '#555555',

        );
        set_theme_mod( 'yuma_theme_options', $yuma_theme_options );
    }
endif;
add_action( 'after_setup_theme', 'yuma_store_set_theme_mods' );
